#!/usr/bin/env python3
# -*- encoding: utf-8 -*'
# https://www.yellowbridge.com/chinese/syllabary.php
# Pinyin 	Wade-Giles 	Yale 	Zhuyin (Bopomofo)
TABLE = '''Pinyin 	WadeGiles 	Yale 	Zhuyin
a 	a 	a 	ㄚ
ai 	ai 	ai 	ㄞ
an 	an 	an 	ㄢ
ang 	ang 	ang 	ㄤ
ao 	ao 	au 	ㄠ
ba 	pa 	ba 	ㄅㄚ
bai 	pai 	bai 	ㄅㄞ
ban 	pan 	ban 	ㄅㄢ
bang 	pang 	bang 	ㄅㄤ
bao 	pao 	bao 	ㄅㄠ
bei 	pei 	bei 	ㄅㄟ
ben 	pen 	ben 	ㄅㄣ
beng 	peng 	beng 	ㄅㄥ
bi 	pi 	bi 	ㄅㄧ
bian 	pien 	byan 	ㄅㄧㄢ
biao 	piao 	byau 	ㄅㄧㄠ
bie 	pieh 	bye 	ㄅㄧㄝ
bin 	pin 	bin 	ㄅㄧㄣ
bing 	ping 	bing 	ㄅㄧㄥ
bo 	po 	bwo 	ㄅㄛ
bu 	pu 	bu 	ㄅㄨ
ca 	ts`a 	tsa 	ㄘㄚ
cai 	ts`ai 	tsai 	ㄘㄞ
can 	ts`an 	tsan 	ㄘㄢ
cang 	ts`ang 	tsang 	ㄘㄤ
cao 	ts`ao 	tsau 	ㄘㄠ
ce 	ts`e 	tse 	ㄘㄜ
cen 	ts`en 	tsen 	ㄘㄣ
ceng 	ts`eng 	tseng 	ㄘㄥ
cha 	ch`a 	cha 	ㄔㄚ
chai 	ch`ai 	chai 	ㄔㄞ
chan 	ch`an 	chan 	ㄔㄢ
chang 	ch`ang 	chang 	ㄔㄤ
chao 	ch`ao 	chau 	ㄔㄠ
che 	ch`e 	che 	ㄔㄜ
chen 	ch`en 	chen 	ㄔㄣ
cheng 	ch`eng 	cheng 	ㄔㄥ
chi 	ch`ih 	chr 	ㄔ
chong 	ch`ung 	chung 	ㄔㄨㄥ
chou 	ch`ou 	chou 	ㄔㄡ
chu 	ch`u 	chu 	ㄔㄨ
chua 	chua 	chwa 	ㄔㄨㄚ
chuai 	ch`uai 	chwai 	ㄔㄨㄞ
chuan 	ch`uan 	chwan 	ㄔㄨㄢ
chuang 	ch`uang 	chwang 	ㄔㄨㄤ
chui 	ch`ui 	chwei 	ㄔㄨㄟ
chun 	ch`un 	chwun 	ㄔㄨㄣ
chuo 	ch`o 	chwo 	ㄔㄨㄛ
ci 	tz`u 	tsz 	ㄘ
cong 	ts`ung 	tsung 	ㄘㄨㄥ
cou 	ts`ou 	tsou 	ㄘㄡ
cu 	ts`u 	tsu 	ㄘㄨ
cuan 	ts`uan 	tsuan 	ㄘㄨㄢ
cui 	ts`ui 	tsui 	ㄘㄨㄟ
cun 	ts`un 	tsun 	ㄘㄨㄣ
cuo 	ts`o 	tso 	ㄘㄨㄛ
da 	ta 	da 	ㄉㄚ
dai 	tai 	dai 	ㄉㄞ
dan 	tan 	dan 	ㄉㄢ
dang 	tang 	dang 	ㄉㄤ
dao 	tao 	dao 	ㄉㄠ
de 	te 	de 	ㄉㄜ
deng 	teng 	deng 	ㄉㄥ
di 	ti 	di 	ㄉㄧ
dian 	tien 	dyan 	ㄉㄧㄢ
diang 	tiang 	dyang 	ㄉㄧㄤ
diao 	tiao 	dyau 	ㄉㄧㄠ
die 	tieh 	dye 	ㄉㄧㄝ
ding 	ting 	ding 	ㄉㄧㄥ
diu 	tiu 	dyou 	ㄉㄧㄡ
dong 	tung 	dung 	ㄉㄨㄥ
dou 	tou 	dou 	ㄉㄡ
du 	tu 	du 	ㄉㄨ
duan 	tuan 	dwan 	ㄉㄨㄢ
dui 	tui 	dwei 	ㄉㄨㄟ
dun 	tun 	dwun 	ㄉㄨㄣ
duo 	to 	dwo 	ㄉㄨㄛ
e 	o 	e 	ㄜ
ei 	ei 	ei 	ㄟ
en 	en 	en 	ㄣ
er 	erh 	er 	ㄦ
fa 	fa 	fa 	ㄈㄚ
fan 	fan 	fan 	ㄈㄢ
fang 	fang 	fang 	ㄈㄤ
fei 	fei 	fei 	ㄈㄟ
fen 	fen 	fen 	ㄈㄣ
feng 	feng 	feng 	ㄈㄥ
fo 	fo 	fwo 	ㄈㄛ
fou 	fou 	fou 	ㄈㄡ
fu 	fu 	fu 	ㄈㄨ
ga 	ka 	ga 	ㄍㄚ
gai 	kai 	gai 	ㄍㄞ
gan 	kan 	gan 	ㄍㄢ
gang 	kang 	gang 	ㄍㄤ
gao 	kao 	gau 	ㄍㄠ
ge 	ko 	ge 	ㄍㄜ
gei 	kei 	gei 	ㄍㄟ
gen 	ken 	gen 	ㄍㄣ
geng 	keng 	geng 	ㄍㄥ
gong 	kung 	gung 	ㄍㄨㄥ
gou 	kou 	gou 	ㄍㄡ
gu 	ku 	gu 	ㄍㄨ
gua 	kua 	gwa 	ㄍㄨㄚ
guai 	kuai 	gwai 	ㄍㄨㄞ
guan 	kuan 	gwan 	ㄍㄨㄢ
guang 	kuang 	gwang 	ㄍㄨㄤ
gui 	kuei 	gwei 	ㄍㄨㄟ
gun 	kun 	gwun 	ㄍㄨㄣ
guo 	kuo 	gwo 	ㄍㄨㄛ
ha 	ha 	ha 	ㄏㄚ
hai 	hai 	hai 	ㄏㄞ
han 	han 	han 	ㄏㄢ
hang 	hang 	hang 	ㄏㄤ
hao 	hao 	hau 	ㄏㄠ
he 	ho 	he 	ㄏㄜ
hei 	hei 	hei 	ㄏㄟ
hen 	hen 	hen 	ㄏㄣ
heng 	heng 	heng 	ㄏㄥ
hong 	hung 	hung 	ㄏㄨㄥ
hou 	hou 	hou 	ㄏㄡ
hu 	hu 	hu 	ㄏㄨ
hua 	hua 	hwa 	ㄏㄨㄚ
huai 	huai 	hwai 	ㄏㄨㄞ
huan 	huan 	hwan 	ㄏㄨㄢ
huang 	huang 	hwang 	ㄏㄨㄤ
hui 	hui 	hwei 	ㄏㄨㄟ
hun 	hun 	hwun 	ㄏㄨㄣ
huo 	huo 	hwo 	ㄏㄨㄛ
ji 	chi 	ji 	ㄐㄧ
jia 	chia 	jya 	ㄐㄧㄚ
jian 	chien 	jyan 	ㄐㄧㄢ
jiang 	chiang 	jyang 	ㄐㄧㄤ
jiao 	chiao 	jyau 	ㄐㄧㄠ
jie 	chieh 	jye 	ㄐㄧㄝ
jin 	chin 	jin 	ㄐㄧㄣ
jing 	ching 	jing 	ㄐㄧㄥ
jiong 	chiung 	jyung 	ㄐㄩㄥ
jiu 	chiu 	jyu 	ㄐㄧㄡ
ju 	chü 	chü 	ㄐㄩ
juan 	chüan 	jywan 	ㄐㄩㄢ
jue 	chüeh 	jywe 	ㄐㄩㄝ
jun 	chün 	jyun 	ㄐㄩㄣ
ka 	k`a 	ka 	ㄎㄚ
kai 	k`ai 	kai 	ㄎㄞ
kan 	k`an 	kan 	ㄎㄢ
kang 	k`ang 	kang 	ㄎㄤ
kao 	k`ao 	kau 	ㄎㄠ
ke 	k`o 	ke 	ㄎㄜ
ken 	k`en 	ken 	ㄎㄣ
keng 	k`eng 	keng 	ㄎㄥ
kong 	k`ung 	kung 	ㄎㄨㄥ
kou 	k`ou 	kou 	ㄎㄡ
ku 	k`u 	ku 	ㄎㄨ
kua 	k`ua 	kwa 	ㄎㄨㄚ
kuai 	k`uai 	kwai 	ㄎㄨㄞ
kuan 	k`uan 	kwan 	ㄎㄨㄢ
kuang 	k`uang 	kwang 	ㄎㄨㄤ
kui 	k`uei 	kwei 	ㄎㄨㄟ
kun 	k`un 	kwun 	ㄎㄨㄣ
kuo 	k`uo 	kwo 	ㄎㄨㄛ
la 	la 	la 	ㄌㄚ
lai 	lai 	lai 	ㄌㄞ
lan 	lan 	lan 	ㄌㄢ
lang 	lang 	lang 	ㄌㄤ
lao 	lao 	lau 	ㄌㄠ
le 	le 	le 	ㄌㄜ
lei 	lei 	lei 	ㄌㄟ
leng 	leng 	leng 	ㄌㄥ
li 	li 	li 	ㄌㄧ
lian 	lien 	lien 	ㄌㄧㄢ
liang 	liang 	liang 	ㄌㄧㄤ
liao 	liao 	liao 	ㄌㄧㄠ
lie 	lieh 	lieh 	ㄌㄧㄝ
lin 	lin 	lin 	ㄌㄧㄣ
ling 	ling 	ling 	ㄌㄧㄥ
liu 	liu 	liu 	ㄌㄧㄡ
long 	lung 	lung 	ㄌㄨㄥ
lou 	lou 	lou 	ㄌㄡ
lu 	lu 	lu 	ㄌㄨ
lü 	lü 	lü 	ㄌㄩ
luan 	luan 	luan 	ㄌㄨㄢ
lüe 	lüeh 	lüeh 	ㄌㄩㄝ
lun 	lun 	lun 	ㄌㄨㄣ
luo 	lo 	lo 	ㄌㄨㄛ
ma 	ma 	ma 	ㄇㄚ
mai 	mai 	mai 	ㄇㄞ
man 	man 	man 	ㄇㄢ
mang 	mang 	mang 	ㄇㄤ
mao 	mao 	mau 	ㄇㄠ
mei 	mei 	mei 	ㄇㄟ
men 	men 	men 	ㄇㄣ
meng 	meng 	meng 	ㄇㄥ
mi 	mi 	mi 	ㄇㄧ
mian 	mien 	myan 	ㄇㄧㄢ
miao 	miao 	miau 	ㄇㄧㄠ
mie 	mieh 	mye 	ㄇㄧㄝ
min 	min 	min 	ㄇㄧㄣ
ming 	ming 	ming 	ㄇㄧㄥ
miu 	miu 	myou 	ㄇㄧㄡ
mo 	mo 	mwo 	ㄇㄨㄛ
mou 	mou 	mou 	ㄇㄡ
mu 	mu 	mu 	ㄇㄨ
na 	na 	na 	ㄋㄚ
nai 	nai 	nai 	ㄋㄞ
nan 	nan 	nan 	ㄋㄢ
nang 	nang 	nang 	ㄋㄤ
nao 	nao 	nau 	ㄋㄠ
ne 	ne 	ne 	ㄋㄛ
nei 	nei 	nei 	ㄋㄟ
nen 	nen 	nen 	ㄋㄣ
neng 	neng 	neng 	ㄋㄥ
ni 	ni 	ni 	ㄋㄧ
nia 	nia 	nya 	ㄋㄧㄚ
nian 	nien 	nyan 	ㄋㄧㄢ
niang 	niang 	nyang 	ㄋㄧㄤ
niao 	niao 	nyau 	ㄋㄧㄠ
nie 	nie 	nye 	ㄋㄧㄝ
nin 	nin 	nin 	ㄋㄧㄣ
ning 	ning 	ning 	ㄋㄧㄥ
niu 	niu 	nyou 	ㄋㄧㄡ
nong 	nung 	nung 	ㄋㄨㄥ
nou 	nou 	nou 	ㄋㄡ
nu 	nu 	nu 	ㄋㄨ
nü 	nü 	nyu 	ㄋㄩ
nuan 	nuan 	nwan 	ㄋㄨㄢ
nüe 	nüeh 	nywe 	ㄋㄩㄝ
nuo 	no 	no 	ㄋㄨㄛ
nun 	nuen 	nwen 	ㄋㄨㄣ
ou 	ou 	ou 	ㄡ
pa 	p`a 	pa 	ㄆㄚ
pai 	p`ai 	pai 	ㄆㄞ
pan 	p`an 	pan 	ㄆㄢ
pang 	p`ang 	pang 	ㄆㄤ
pao 	p`ao 	pau 	ㄆㄠ
pei 	p`ei 	pei 	ㄆㄟ
pen 	p`en 	pen 	ㄆㄣ
peng 	p`eng 	peng 	ㄆㄥ
pi 	p`i 	pi 	ㄆㄧ
pian 	p`ien 	pyan 	ㄆㄧㄢ
piao 	p`iao 	pyau 	ㄆㄧㄠ
pie 	p`ieh 	pye 	ㄆㄧㄝ
pin 	p`in 	pin 	ㄆㄧㄣ
ping 	p`ing 	ping 	ㄆㄧㄥ
po 	p`o 	pwo 	ㄆㄨㄛ
pou 	p`ou 	pou 	ㄆㄡ
pu 	p`u 	pu 	ㄆㄨ
qi 	ch`i 	chi 	ㄑㄧ
qia 	ch`ia 	chya 	ㄑㄧㄚ
qian 	ch`ien 	chyan 	ㄑㄧㄢ
qiang 	ch`iang 	chyang 	ㄑㄧㄤ
qiao 	ch`iao 	chyau 	ㄑㄧㄠ
qie 	ch`ieh 	chye 	ㄑㄧㄝ
qin 	ch`in 	chin 	ㄑㄧㄣ
qing 	ch`ing 	ching 	ㄑㄧㄥ
qiong 	ch`iung 	chyung 	ㄑㄩㄥ
qiu 	ch`iu 	chyou 	ㄑㄧㄡ
qu 	ch`ü 	chyu 	ㄑㄩ
quan 	ch`üan 	chywan 	ㄑㄩㄢ
que 	ch`üeh 	chyweh 	ㄑㄩㄝ
qun 	ch`ün 	chyun 	ㄑㄩㄣ
ran 	jan 	ran 	ㄖㄢ
rang 	jang 	rang 	ㄖㄤ
rao 	jao 	rau 	ㄖㄠ
re 	je 	re 	ㄖㄜ
ren 	jen 	ren 	ㄖㄣ
reng 	jeng 	reng 	ㄖㄥ
ri 	jih 	r 	ㄖ
rong 	jung 	rung 	ㄖㄨㄥ
rou 	jou 	rou 	ㄖㄡ
ru 	ju 	ru 	ㄖㄨ
ruan 	juan 	rwan 	ㄖㄨㄢ
rui 	jui 	rwei 	ㄖㄨㄟ
run 	jun 	rwun 	ㄖㄨㄣ
ruo 	jo 	rwo 	ㄖㄨㄛ
sa 	sa 	sa 	ㄙㄚ
sai 	sai 	sai 	ㄙㄞ
san 	san 	san 	ㄙㄢ
sang 	sang 	sang 	ㄙㄤ
sao 	sao 	sau 	ㄙㄠ
se 	se 	se 	ㄙㄜ
sei 	sei 	sei 	ㄙㄟ
sen 	sen 	sen 	ㄙㄣ
seng 	seng 	seng 	ㄙㄥ
sha 	sha 	sha 	ㄕㄚ
shai 	shai 	shai 	ㄕㄞ
shan 	shan 	shan 	ㄕㄢ
shang 	shang 	shang 	ㄕㄤ
shao 	shao 	shau 	ㄕㄠ
she 	she 	she 	ㄕㄜ
shei 	shei 	shei 	ㄕㄟ
shen 	shen 	shen 	ㄕㄣ
sheng 	sheng 	sheng 	ㄕㄥ
shi 	shih 	shr 	ㄕ
shong 	shung 	shung 	ㄕㄡㄥ
shou 	shou 	shou 	ㄕㄡ
shu 	shu 	shu 	ㄕㄨ
shua 	shua 	shwa 	ㄕㄨㄚ
shuai 	shuai 	shwai 	ㄕㄨㄞ
shuan 	shuan 	shwan 	ㄕㄨㄢ
shuang 	shuang 	shwang 	ㄕㄨㄤ
shui 	shui 	shwei 	ㄕㄨㄟ
shun 	shun 	shwun 	ㄕㄨㄣ
shuo 	shuo 	shwo 	ㄕㄨㄛ
si 	ssu 	sz 	ㄙ
song 	sung 	sung 	ㄙㄨㄥ
sou 	sou 	sou 	ㄙㄡ
su 	su 	su 	ㄙㄨ
suan 	suan 	swan 	ㄙㄨㄢ
sui 	sui 	swei 	ㄙㄨㄟ
sun 	sun 	swun 	ㄙㄨㄣ
suo 	so 	swo 	ㄙㄨㄛ
ta 	t`a 	ta 	ㄊㄚ
tai 	t`ai 	tai 	ㄊㄞ
tan 	t`an 	tan 	ㄊㄢ
tang 	t`ang 	tang 	ㄊㄤ
tao 	t`ao 	tau 	ㄊㄠ
te 	t`e 	te 	ㄊㄜ
teng 	t`eng 	teng 	ㄊㄥ
ti 	t`i 	ti 	ㄊㄧ
tian 	t`ien 	tyan 	ㄊㄧㄢ
tiao 	t`iao 	tyau 	ㄊㄧㄠ
tie 	t`ieh 	tye 	ㄊㄧㄝ
ting 	t`ing 	ting 	ㄊㄧㄥ
tong 	t`ung 	tung 	ㄊㄨㄥ
tou 	t`ou 	tou 	ㄊㄡ
tu 	t`u 	tu 	ㄊㄨ
tuan 	t`uan 	twan 	ㄊㄨㄢ
tui 	t`ui 	twei 	ㄊㄨㄟ
tun 	t`un 	twun 	ㄊㄨㄣ
tuo 	t`o 	two 	ㄊㄨㄛ
wa 	wa 	wa 	ㄨㄚ
wai 	wai 	wai 	ㄨㄞ
wan 	wan 	wan 	ㄨㄢ
wang 	wang 	wang 	ㄨㄤ
wei 	wei 	wei 	ㄨㄟ
wen 	wen 	wen 	ㄨㄣ
weng 	weng 	weng 	ㄨㄥ
wo 	wo 	wo 	ㄨㄛ
wu 	wu 	wu 	ㄨ
xi 	hsi 	syi 	ㄒㄧ
xia 	hsia 	syia 	ㄒㄧㄚ
xian 	hsien 	syan 	ㄒㄧㄢ
xiang 	hsiang 	syang 	ㄒㄧㄤ
xiao 	hsiao 	syau 	ㄒㄧㄠ
xie 	hsieh 	sywe 	ㄒㄧㄝ
xin 	hsin 	syin 	ㄒㄧㄣ
xing 	hsing 	sying 	ㄒㄧㄥ
xiong 	hsiung 	syung 	ㄒㄩㄥ
xiu 	hsiu 	syu 	ㄒㄧㄡ
xu 	hsü 	syü 	ㄒㄩ
xuan 	hsüan 	sywan 	ㄒㄩㄢ
xue 	hsüeh 	sywe 	ㄒㄩㄝ
xun 	hsün 	syun 	ㄒㄩㄣ
ya 	ya 	ya 	ㄧㄚ
yai 	yai 	yai 	ㄧㄞ
yan 	yen 	yan 	ㄧㄢ
yang 	yang 	yang 	ㄧㄤ
yao 	yao 	yau 	ㄧㄠ
ye 	yeh 	ye 	ㄧㄝ
yi 	i 	yi 	ㄧ
yin 	yin 	yin 	ㄧㄣ
ying 	ying 	ying 	ㄧㄥ
yo 	yo 	yo 	ㄧㄛ
yong 	yung 	yung 	ㄩㄥ
you 	yu 	you 	ㄧㄡ
yu 	yü 	yü 	ㄩ
yuan 	yüan 	ywan 	ㄩㄢ
yue 	yüeh 	ywe 	ㄩㄝ
yun 	yün 	yün 	ㄩㄣ
za 	tsa 	dza 	ㄗㄚ
zai 	tsai 	dzai 	ㄗㄞ
zan 	tsan 	dzan 	ㄗㄢ
zang 	tsang 	dzang 	ㄗㄤ
zao 	tsao 	dzau 	ㄗㄠ
ze 	tse 	dze 	ㄗㄜ
zei 	tsei 	dzei 	ㄗㄟ
zen 	tsen 	dzen 	ㄗㄣ
zeng 	tseng 	dzeng 	ㄗㄥ
zha 	cha 	ja 	ㄓㄚ
zhai 	chai 	jai 	ㄓㄞ
zhan 	chan 	jan 	ㄓㄢ
zhang 	chang 	jang 	ㄓㄤ
zhao 	chao 	jau 	ㄓㄠ
zhe 	che 	je 	ㄓㄜ
zhei 	chei 	jei 	ㄓㄟ
zhen 	chen 	jen 	ㄓㄣ
zheng 	cheng 	jeng 	ㄓㄥ
zhi 	chih 	jr 	ㄓ
zhong 	chung 	jung 	ㄓㄨㄥ
zhou 	chou 	jou 	ㄓㄡ
zhu 	chu 	ju 	ㄓㄨ
zhua 	chua 	jwa 	ㄓㄨㄚ
zhuai 	chuai 	jwai 	ㄓㄨㄞ
zhuan 	chuan 	jwan 	ㄓㄨㄢ
zhuang 	chuang 	jwang 	ㄓㄨㄤ
zhui 	chui 	jwei 	ㄓㄨㄟ
zhun 	chun 	jwun 	ㄓㄨㄣ
zhuo 	cho 	jwo 	ㄓㄨㄛ
zi 	tzu 	dz 	ㄗ
zong 	tsung 	dzung 	ㄗㄨㄥ
zou 	tsou 	dzou 	ㄗㄡ
zu 	tsu 	dzu 	ㄗㄨ
zuan 	tsuan 	dzwan 	ㄗㄨㄢ
zui 	tsui 	dzwei 	ㄗㄨㄟ
zun 	tsun 	dzwun 	ㄗㄨㄣ
zuo 	tso 	dzwo 	ㄗㄨㄛ'''

print(',\n'.join(str(line.split()) for line in TABLE.replace('ü', 'v').split('\n')))