#!/bin/bash
set -e
self_="$(readlink -f "$0")"
script_dir="${self_%/*}"
root_dir="${script_dir%/*}"
test_dir="$root_dir"/test
export HAPI_DATA_DIR="$root_dir/dat"

mkdir -p "$test_dir"
# ln -sft "$test_dir" '../dat'

cat > "$test_dir/input.txt" <<'INPUT'
汉语拼音，在中国大陆常簡稱为拼音，是一種以拉丁字母作普通话（現代標準漢語）標音的方案。是目前的中文羅馬拼音國際標準規範。汉语拼音在中国大陆作为基础教育内容全面使用，是义务教育的重要内容。在海外，特别是常用現代標準漢語的地区如新加坡、马来西亚、菲律宾和美国唐人街等，目前也在汉语教育中进行汉语拼音教学。臺灣自2008年開始，中文譯音使用原則也採用漢語拼音[1]，但舊護照姓名和部分地名仍採用舊式威妥瑪拼音[2]
INPUT

# Keep this here for testing options such as --tw.
hapi_exe="$script_dir"/hapi
hapi_cmd=("$hapi_exe")

function echoit()
{
  local out_="$1"
  echo "appending to $out_" >&2
  shift
  echo "\$ ${hapi_exe##*/} $@" >> "$out_"
  "${hapi_cmd[@]}" "$@" >> "$out_"
  echo >> "$out_"
}

function testit()
{
  local out_="$1"
  shift
  echoit "$test_dir"/ansi.txt "$@"
  echoit "$test_dir"/bbcode.txt --target bbcode "$@"
  "${hapi_cmd[@]}" --html "$out_" "$@"
  echo "generated $out_" >&2
}

> "$test_dir"/ansi.txt
> "$test_dir"/bbcode.txt

# Colorized text.
testit \
  "$test_dir"/text_with_pinyin.htm \
  --color mdbg -p pinyin --file "$(realpath --relative-to="$PWD" "$test_dir"/input.txt)"

testit \
  "$test_dir"/text_with_zhuyin.htm \
  --color mdbg -p zhuyin --file "$(realpath --relative-to="$PWD" "$test_dir"/input.txt)"

testit \
  "$test_dir"/text_with_pinyin_and_zhuyin.htm \
  --color mdbg -p pinyin zhuyin --file "$(realpath --relative-to="$PWD" "$test_dir"/input.txt)"

# Hanzi to Pinyin table.
testit \
  "$test_dir"/h2p.htm \
  --color mdbg --table h2p --phonetics pinyin zhuyin yale -- '教常簡稱'

# Pinyin to Hanzi table.
testit \
  "$test_dir"/p2h.htm \
  --color dummit --table p2h deng3 cháng qian

cat "$test_dir"/ansi.txt

